@@ -3,7 +3,7 @@
 //
 // Invenio RDM Records is free software; you can redistribute it and/or modify it
 // under the terms of the MIT License; see LICENSE file for more details.
-import { http } from "./config";
+import { http } from "react-invenio-forms";
 
 export class RequestEventsLinksExtractor {
   #links;
@@ -28,11 +28,11 @@ export class InvenioRequestEventsApi {
   }
 
   getComment = async () => {
-    return await http.get(this.#links.eventUrl);
+    return await http.get(this.#links.eventUrl, { params: { expand: 1 } });
   };
 
   updateComment = async (payload) => {
-    return http.put(this.#links.eventUrl, payload);
+    return http.put(this.#links.eventUrl, payload, { params: { expand: 1 } });
   };
 
   deleteComment = async () => {
