@@ -9,7 +9,7 @@ import PropTypes from "prop-types";
 import React, { Component } from "react";
 import { Image } from "react-invenio-forms";
 import Overridable from "react-overridable";
-import { Divider, Header, Message } from "semantic-ui-react";
+import { Divider, Header, Icon, Message } from "semantic-ui-react";
 import { toRelativeTime } from "react-invenio-forms";
 import RequestStatus from "./RequestStatus";
 import RequestTypeLabel from "./RequestTypeLabel";
@@ -24,30 +24,34 @@ const User = ({ user }) => (
       ui={false}
       rounded
     />
-    <span>{user.profile?.full_name || user.username}</span>
+    <span>{user.profile?.full_name || user?.username || user?.email || i18next.t("Anonymous user")}
+    </span>
   </div>
 );
 const Community = ({ community }) => (
   <div className="flex">
-    <Image
-      src={community.links.logo}
-      avatar
-      size="tiny"
-      className="mr-5"
-      ui={false}
-    />
+    <Image src={community.links.logo} avatar size="tiny" className="mr-5" ui={false} />
     <a href={`/communities/${community.slug}`}>{community.metadata.title}</a>
   </div>
 );
+const ExternalEmail = ({ email }) => (
+  <div className="flex">
+    <Icon name="mail" className="mr-5" />
+    <span>{i18next.t("External email")}: {email.id}</span>
+  </div>
+);
 
-const UserOrCommunity = ({ userData, details }) => {
+const EntityDetails = ({ userData, details }) => {
   const isUser = "user" in userData;
   const isCommunity = "community" in userData;
+  const isExternalEmail = "email" in userData;
 
   if (isUser) {
     return <User user={details} />;
   } else if (isCommunity) {
     return <Community community={details} />;
+  } else if (isExternalEmail) {
+    return <ExternalEmail email={details} />;
   }
 };
 
@@ -65,18 +69,22 @@ class RequestMetadata extends Component {
     return (
       <Overridable id="InvenioRequest.RequestMetadata.Layout" request={request}>
         <>
-          <Header as="h3" size="tiny">
-            {i18next.t("Creator")}
-          </Header>
-          {this.isResourceDeleted(expandedCreatedBy) ? (
-            <DeletedResource details={expandedCreatedBy} />
-          ) : (
-            <UserOrCommunity
-              userData={request.created_by}
-              details={request.expanded?.created_by}
-            />
-          )}
-          <Divider />
+          {expandedCreatedBy !== undefined &&
+            <>
+              <Header as="h3" size="tiny">
+                {i18next.t("Creator")}
+              </Header>
+              {this.isResourceDeleted(expandedCreatedBy) ? (
+                <DeletedResource details={expandedCreatedBy} />
+              ) : (
+                <EntityDetails
+                  userData={request.created_by}
+                  details={request.expanded?.created_by}
+                />
+              )}
+              <Divider />
+            </>
+          }
 
           <Header as="h3" size="tiny">
             {i18next.t("Receiver")}
@@ -84,7 +92,7 @@ class RequestMetadata extends Component {
           {this.isResourceDeleted(expandedReceiver) ? (
             <DeletedResource details={expandedReceiver} />
           ) : (
-            <UserOrCommunity
+            <EntityDetails
               userData={request.receiver}
               details={request.expanded?.receiver}
             />
