@@ -5,13 +5,17 @@
 // under the terms of the MIT License; see LICENSE file for more details.
 
 import { connect } from "react-redux";
-import {getTimelineWithRefresh, setPage, timelineStopRefresh} from "./state/actions";
+import {
+  getTimelineWithRefresh,
+  setPage,
+  clearTimelineInterval,
+} from "./state/actions";
 import TimelineFeedComponent from "./TimelineFeed";
 
 const mapDispatchToProps = (dispatch) => ({
   getTimelineWithRefresh: () => dispatch(getTimelineWithRefresh()),
-  timelineStopRefresh: () => dispatch(timelineStopRefresh()),
-  setPage: (page) => dispatch(setPage(page))
+  timelineStopRefresh: () => dispatch(clearTimelineInterval()),
+  setPage: (page) => dispatch(setPage(page)),
 });
 
 const mapStateToProps = (state) => ({
@@ -21,7 +25,7 @@ const mapStateToProps = (state) => ({
   error: state.timeline.error,
   isSubmitting: state.timelineCommentEditor.isLoading,
   size: state.timeline.size,
-  page: state.timeline.page
+  page: state.timeline.page,
 });
 
 export const Timeline = connect(
